-- understanding common table expression (cte) in postgresql using dvdrental database
with ctedata as 
(
	select f.title,
	       f.film_id,
	       f.replacement_cost,
	       f.rental_rate,
	       count(distinct( i1.inventory_id ))                                 as numberofcds,
	       count (r.rental_id)                                                as numberofrentals,
	       count(distinct( i1.inventory_id )) * ( f.replacement_cost * 0.33 ) as invested,
	       count(r.rental_id) * f.rental_rate                                 as sales,
	       ( count(r.rental_id) * f.rental_rate ) - count(distinct( i1.inventory_id )) * ( f.replacement_cost * 0.33 ) as profitorloss
	from   film f
	       join inventory i1
	         on ( i1.film_id = f.film_id )
	       join rental r
	         on ( r.inventory_id = i1.inventory_id )
	group  by f.title,
	          f.film_id,
	          f.replacement_cost,
	          f.rental_rate
)
select 
  sum(cte.invested) as invested_amount, 
  sum(cte.sales) as gross_sales, 
  sum(cte.profitorloss) as profit_or_loss 
from 
  ctedata cte;
